@@ -3,7 +3,7 @@ package Database::Async::ORM::Field;
 use strict;
 use warnings;
 
-our $VERSION = '0.018'; # VERSION
+our $VERSION = '0.019'; # VERSION
 
 sub new {
     my ($class, %args) = @_;
@@ -12,8 +12,10 @@ sub new {
 
 sub table { shift->{table} }
 sub name { shift->{name} }
+sub attributes { shift->{attributes} }
 sub type { shift->{type} }
 sub nullable { shift->{nullable} }
+sub default { shift->{default} }
 
 1;
 
